@@ -18,7 +18,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -92,7 +94,7 @@ file_guess_method (sw_sample * sample, char * pathname);
 static sw_file_format_desc file_formats [] = {
   {
     SWEEP_FILE_FORMAT_RAW,
-    "Raw PCM (headerless)",
+    N_("Raw PCM (headerless)"),
     "raw",
   },
   {
@@ -266,7 +268,7 @@ sample_load (char * pathname)
 static void
 sample_load_destroy_cb (GtkWidget * widget, gpointer data)
 {
-  /*sample_bank_remove (NULL);*/
+  sample_bank_remove (NULL);
 }
 
 static void
@@ -677,7 +679,7 @@ create_save_menu (sw_sample * sample)
 
   for (i = 0; i < sizeof(file_formats)/sizeof(sw_file_format_desc); i++) {
     desc = &file_formats[i];
-    menuitem = gtk_menu_item_new_with_label (desc->name);
+    menuitem = gtk_menu_item_new_with_label (_(desc->name));
     gtk_menu_append (GTK_MENU(menu), menuitem);
     gtk_object_set_data (GTK_OBJECT(menuitem), "method",
 			 GINT_TO_POINTER(SWEEP_FILE_METHOD_LIBSNDFILE));
@@ -697,7 +699,7 @@ create_save_menu (sw_sample * sample)
 #if 1
   /* MP3 (encoding not supported due to patent restrictions) */
 
-  menuitem = gtk_menu_item_new_with_label ("MP3 (Use Ogg Vorbis instead)");
+  menuitem = gtk_menu_item_new_with_label (_("MP3 (Use Ogg Vorbis instead)"));
   gtk_widget_set_sensitive (menuitem, FALSE);
   gtk_menu_append (GTK_MENU(menu), menuitem);
   gtk_widget_show (menuitem);
