@@ -51,7 +51,9 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
 #ifdef HAVE_SPEEX
 
@@ -1213,6 +1215,12 @@ static sw_choice feature_choices[] = {
     N_("CBR with VAD and Discontinuous Transmission (DTX)"),
     N_("DTX marks extended pauses with a minimum bitrate signal")
   },
+  { FEAT_VBR | FEAT_VAD,
+    N_("Variable bitrate (VBR) with VAD"),
+    N_("VBR allows the bitrate to adapt to the complexity of the speech; "
+       "this selection uses VBR without DTX, which may improve performance "
+       "compared to full VBR in the presence of background noise.")
+  },
   { FEAT_VBR | FEAT_VAD | FEAT_DTX,
     N_("Variable bitrate (VBR) with all features"),
     N_("VBR allows the bitrate to adapt to the complexity of the speech, "
@@ -1660,7 +1668,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 
   for (i = 0; mode_choices[i].name != NULL; i++) {
     menuitem =
-      gtk_menu_item_new_with_label (mode_choices[i].name);
+      gtk_menu_item_new_with_label (_(mode_choices[i].name));
     gtk_menu_append (GTK_MENU(menu), menuitem);
     gtk_object_set_user_data (GTK_OBJECT(menuitem),
 			      GINT_TO_POINTER(mode_choices[i].number));
@@ -1701,7 +1709,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 
   for (i = 0; feature_choices[i].name != NULL; i++) {
     menuitem =
-      gtk_menu_item_new_with_label (feature_choices[i].name);
+      gtk_menu_item_new_with_label (_(feature_choices[i].name));
     gtk_menu_append (GTK_MENU(menu), menuitem);
     gtk_object_set_user_data (GTK_OBJECT(menuitem),
 			      GINT_TO_POINTER(feature_choices[i].number));
@@ -1713,7 +1721,7 @@ create_speex_encoding_options_dialog (sw_sample * sample, char * pathname)
 
     if (feature_choices[i].desc != NULL) {
       tooltips = gtk_tooltips_new ();
-      gtk_tooltips_set_tip (tooltips, menuitem, feature_choices[i].desc,
+      gtk_tooltips_set_tip (tooltips, menuitem, _(feature_choices[i].desc),
 			    NULL);
     }
   }
