@@ -437,7 +437,7 @@ head_controller_create (sw_head * head, GtkWidget * window,
     gtk_widget_show (tool_hbox);
 
     button = create_pixmap_button (window, playrev_xpm,
-				   "Reverse mode (toggle)",
+				   _("Reverse mode (toggle)"),
 				   style, SW_TOOLBAR_TOGGLE_BUTTON,
 				   hctl_reverse_toggled_cb, NULL, NULL, hctl);
 
