@@ -32,6 +32,7 @@
 #include <glib.h>
 #include <gmodule.h>
 
+#include <sweep/sweep_i18n.h>
 #include <sweep/sweep_version.h>
 #include <sweep/sweep_types.h>
 
@@ -41,7 +42,7 @@ GList * plugins = NULL;
 static gint
 cmp_proc_names (sw_procedure * a, sw_procedure * b)
 {
-  return strcmp (a->name, b->name);
+  return strcmp (_(a->name), _(b->name));
 }
 
 void
