@@ -18,6 +18,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -1682,7 +1686,7 @@ sample_selection_insert_tmp_sel (sw_sample * s)
   sw_format * format = s->sounddata->format;
   sw_sel * sel;
 
-  n = snprintf (buf, BUF_LEN, "Insert selection [");
+  n = snprintf (buf, BUF_LEN, _("Insert selection ["));
   n += snprint_time (buf+n, BUF_LEN-n,
 		     frames_to_time (format, s->tmp_sel->sel_start));
   n += snprintf (buf+n, BUF_LEN-n, " - ");
@@ -1735,7 +1739,7 @@ sample_selection_subtract_tmp_sel (sw_sample * s)
   sw_format * format = s->sounddata->format;
   sw_sel * sel;
 
-  n = snprintf (buf, BUF_LEN, "Subtract selection [");
+  n = snprintf (buf, BUF_LEN, _("Subtract selection ["));
   n += snprint_time (buf+n, BUF_LEN-n,
 		     frames_to_time (format, s->tmp_sel->sel_start));
   n += snprintf (buf+n, BUF_LEN-n, " - ");
@@ -1780,7 +1784,7 @@ sample_selection_replace_with_tmp_sel (sw_sample * s)
   sw_format * format = s->sounddata->format;
   sw_sel * sel;
 
-  n = snprintf (buf, BUF_LEN, "Set selection [");
+  n = snprintf (buf, BUF_LEN, _("Set selection ["));
   n += snprint_time (buf+n, BUF_LEN-n,
 		     frames_to_time (format, s->tmp_sel->sel_start));
   n += snprintf (buf+n, BUF_LEN-n, " - ");
@@ -1859,11 +1863,13 @@ sample_info_dialog_ok_cb (GtkWidget * widget, gpointer data)
   gtk_widget_hide (dialog);
 }
 
+/*
 static gchar * filename_info[] = { N_("Filename:"), "" };
 static gchar * rate_info[] = { N_("Sampling rate:"), "" };
 static gchar * channels_info[] = { N_("Channels:"), "" };
 static gchar * size_info[] = { N_("Data memory:"), "" };
 static gchar * duration_info[] = { N_("Duration:"), "" };
+*/
 
 void
 sample_show_info_dialog (sw_sample * sample)
@@ -1871,6 +1877,8 @@ sample_show_info_dialog (sw_sample * sample)
   GtkWidget * dialog;
   GtkWidget * clist;
   GtkWidget * ok_button;
+  gchar * list_item[] = { "" };
+  gint i=0;
 
   if (sample->info_clist == NULL) {
     dialog = gtk_dialog_new ();
@@ -1890,12 +1898,24 @@ sample_show_info_dialog (sw_sample * sample)
 					GTK_JUSTIFY_LEFT);
     gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), clist,
 			FALSE, FALSE, 0);
-    
+    /*    
     gtk_clist_append (GTK_CLIST(clist), filename_info);
     gtk_clist_append (GTK_CLIST(clist), rate_info);
     gtk_clist_append (GTK_CLIST(clist), channels_info);
     gtk_clist_append (GTK_CLIST(clist), size_info);
     gtk_clist_append (GTK_CLIST(clist), duration_info);
+    */
+     
+    gtk_clist_append (GTK_CLIST(clist), list_item);
+    gtk_clist_set_text (GTK_CLIST(clist), i++, 0, _("Filename: "));
+    gtk_clist_append (GTK_CLIST(clist), list_item);
+    gtk_clist_set_text (GTK_CLIST(clist), i++, 0, _("Sampling rate: "));
+    gtk_clist_append (GTK_CLIST(clist), list_item);
+    gtk_clist_set_text (GTK_CLIST(clist), i++, 0, _("Channels: "));
+    gtk_clist_append (GTK_CLIST(clist), list_item);
+    gtk_clist_set_text (GTK_CLIST(clist), i++, 0, _("Data memory: "));
+    gtk_clist_append (GTK_CLIST(clist), list_item);
+    gtk_clist_set_text (GTK_CLIST(clist), i++, 0, _("Duration: "));
     
     gtk_clist_set_column_min_width (GTK_CLIST(clist), 0, 120);
     gtk_clist_set_column_min_width (GTK_CLIST(clist), 1, 160);
